<?php
// PHP Layers Menu 2.3.5 (C) 2001-2003 Marco Pratesi (marco at telug dot it)

/**
* This is the base class of the PHP Layers Menu system.
*
* This class depends on the PEAR conforming version of the PHPLib Template class
*
* @version 2.3.5
* @package PHPLayersMenu
*/
class layers_menu
{
	/**
	* URL to be prepended to the menu links
	* @access private
	* @var string
	*/
	var $prepended_url;
	
	var $error = array();

	/**
	* The base directory where the package is installed
	* @access private
	* @var string
	*/
	var $dir_root;
	/**
	* The "lib" directory of the package
	* @access private
	* @var string
	*/
	var $lib_dir;

	/**
	* The directory where images related to the menu can be found
	* @access private
	* @var string
	*/
	var $img_dir;

	/**
	* The string containing the menu structure
	* @access private
	* @var string
	*/
	var $menu_structure;
	/**
	* The character used in the menu structure format to separate fields of each item
	* @access private
	* @var string
	*/
	var $separator;
	/**
	* The character used for the Tree Menu in the menu structure format to separate fields of each item
	* @access private
	* @var string
	*/
	var $tree_menu_separator;
	/**
	* Type of images used for the Tree Menu
	* @access private
	* @var string
	*/
	var $tree_menu_images_type;
	/**
	* An array where we store the Tree Menu code for each menu
	* @access private
	* @var array
	*/
	var $_tree_menu;

	/**
	* It counts nodes for all menus
	* @access private
	* @var integer
	*/
	var $_nodes_count;
	/**
	* A multi-dimensional array where we store informations for each menu entry
	* @access private
	* @var array
	*/
	var $tree;
	/**
	* The maximum hierarchical level of menu items
	* @access private
	* @var integer
	*/
	var $_max_level;
	/**
	* An array that counts the number of first level items for each menu
	* @access private
	* @var array
	*/
	var $_first_Level_count;
	/**
	* An array containing the number identifying the first item of each menu
	* @access private
	* @var array
	*/
	var $_first_item;
	/**
	* An array containing the number identifying the last item of each menu
	* @access private
	* @var array
	*/
	var $_last_item;
	/**
	* An array containing the code related to the first level menu of each menu
	* @access private
	* @var array
	*/
	var $_first_level_menu;

	var $table_name;

	/**
	* Names of fields of the table storing data describing the menu
	*
	* default field names correspond to the same field names foreseen
	* by the menu structure format
	*
	* @access private
	* @var array
	*/
	var $table_fields = array(
		'id'		=> 'id',
		'parent_id'	=> 'parent_id',
		'text'		=> 'text',
		'link'		=> 'link',
		'title'		=> 'title',
		'icon'		=> 'icon',
		'target'	=> 'target',
		'orderfield'	=> 'orderfield',
		'expanded'	=> 'expanded'
	);
	/**
	* A temporary array to store data retrieved from the DB and to perform the depth-first search
	* @access private
	* @var array
	*/
	var $_tmp_array = array();

	/**
	* The constructor method; it initializates the menu system
	* @return void
	*/
	function layers_menu()
	{
		global $phpbb_root_path;
		$this->prepended_url = '';

		$this->dir_root = $phpbb_root_path . 'pafiledb/';
		$this->lib_dir = $this->dir_root . 'lib/';
		$this->img_dir = $this->dir_root . 'images/menu/';

		$this->menu_structure = '';
		$this->separator = '|';
		$this->tree_menu_images_type = 'png';
		$this->_tree_menu = array();

		$this->_nodes_count = 0;
		$this->tree = array();
		$this->_max_level = array();
		$this->_first_level_count = array();
		$this->_first_item = array();
		$this->_last_item = array();
		$this->_first_level_menu = array();
		
		$this->table_name = 'mx_layersmenu';
	}





	/**
	* The method to set the prepended URL
	* @access public
	* @return boolean
	*/
	function set_prepended_url($prepended_url)
	{
		// We do not perform any check
		$this->prependedUrl = $prepended_url;
		return true;
	}

	/**
	* The method to set the dir_root directory
	* @access public
	* @return boolean
	*/
	function set_dir_root($dir_root)
	{
		if (!is_dir($dir_root))
		{
			$this->error("setDirroot: $dirroot is not a directory.");
			return false;
		}

		if (substr($dir_root, -1) != '/')
		{
			$dir_root .= '/';
		}
		$this->dir_root = $dir_root;
		return true;
	}

	/**
	* The method to set the libdir directory
	* @access public
	* @return boolean
	*/
	function set_lib_dir($lib_dir)
	{
		if (substr($lib_dir, -1) == '/')
		{
			$lib_dir = substr($lib_dir, 0, -1);
		}

		if (str_replace('/', '', $lib_dir) == $lib_dir)
		{
			$lib_dir = $this->dir_root . $lib_dir;
		}
		if (!is_dir($lib_dir))
		{
			$this->error("setLibdir: $libdir is not a directory.");
			return false;
		}
		$this->lib_dir = $lib_dir . '/';
		return true;
	}


	/**
	* The method to set the imgdir directory
	* @access public
	* @return boolean
	*/
	function set_img_dir($img_dir)
	{
		if (substr($img_dir, -1) == '/')
		{
			$img_dir = substr($img_dir, 0, -1);
		}
		if (str_replace('/', '', $img_dir) == $img_dir)
		{
			$img_dir = $this->dir_root . $img_dir;
		}
		if (!is_dir($img_dir))
		{
			$this->error("setImgdir: $img_dir is not a directory.");
			return false;
		}
		$this->img_dir = $img_dir . '/';
		return true;
	}

	/**
	* The method to read the menu structure from a file
	* @access public
	* @param string $tree_file the menu structure file
	* @return boolean
	*/
	
	function set_menu_structure_file($tree_file)
	{
		if (!($fp = fopen($tree_file, 'r')))
		{
			$this->error("setMenuStructureFile: unable to open file $tree_file.");
			return false;
		}
		
		$this->menu_structure = '';
		
		while ($buffer = fgets($fp, 4096))
		{
			$buffer = ereg_replace(chr(13), '', $buffer);	// Microsoft Stupidity Suppression
			$this->menu_structure .= $buffer;
		}
		
		fclose($fp);
		
		if ($this->menu_structure == '')
		{
			$this->error("setMenuStructureFile: $tree_file is empty.");
			return false;
		}
		return true;
	}

	/**
	* The method to set the menu structure passing it through a string
	* @access public
	* @param string $tree_string the menu structure string
	* @return boolean
	*/
	function set_menu_structure_string($tree_string)
	{
		$this->menu_structure = ereg_replace(chr(13), '', $tree_string);	// Microsoft Stupidity Suppression
		if ($this->menu_structure == '')
		{
			$this->error("setMenuStructureString: empty string.");
			return false;
		}
		return true;
	}

	/**
	* The method to set the value of separator
	* @access public
	* @return void
	*/
	function set_separator($separator)
	{
		$this->separator = $separator;
	}


	/**
	* The method to set the name of the table storing data describing the menu
	* @access public
	* @param string
	* @return boolean
	*/
	function set_table_name($table_name)
	{
		if (!is_string($table_name))
		{
			$this->error("setTableName: \$table_name is not a string.");
			return false;
		}
		$this->table_name = $table_name;
		return true;
	}

	/**
	* The method to set names of fields of the table storing data describing the menu
	* @access public
	* @param array
	* @return boolean
	*/
	function set_table_fields($table_fields)
	{
		if (!is_array($table_fields))
		{
			$this->error("setTableFields: \$table_fields is not an array.");
			return false;
		}
		
		if (count($table_fields) == 0)
		{
			$this->error("setTableFields: \$table_fields is a zero-length array.");
			return false;
		}

		foreach ($table_fields as $key => $value)
		{
			$this->table_fields[$key] = ($value == '') ? "''" : $value;
		}
		return true;
	}



	/**
	* The method to parse the current menu structure and correspondingly update related variables
	* @access public
	* @param string $menu_name the name to be attributed to the menu
	*   whose structure has to be parsed
	* @return void
	*/
	function parse_structurefor_menu($menu_name = '')
	{
		$this->_max_level[$menu_name] = 0;
		$this->_first_level_count[$menu_name] = 0;
		$this->_first_item[$menu_name] = $this->_nodes_count + 1;
		$cnt = $this->_first_item[$menu_name];
		$menu_structure = $this->menu_structure;

		/* *********************************************** */
		/* Partially based on a piece of code taken from   */
		/* TreeMenu 1.1 - Bjorge Dijkstra (bjorge@gmx.net) */
		/* *********************************************** */

		while ($menu_structure != '')
		{
			$before_cr = strcspn($menu_structure, "\n");
			$buffer = substr($menu_structure, 0, $before_cr);
			$menu_structure = substr($menu_structure, $before_cr + 1);
			if (substr($buffer, 0, 1) != '#')
			{
				$tmp = rtrim($buffer);
				$node = explode($this->separator, $tmp);
				for ($i = count($node); $i <= 6; $i++)
				{
					$node[$i] = '';
				}
				$this->tree[$cnt]['level'] = strlen($node[0]);
				$this->tree[$cnt]['text'] = $node[1];
				$this->tree[$cnt]['link'] = $node[2];
				$this->tree[$cnt]['title'] = $node[3];
				$this->tree[$cnt]['icon'] = $node[4];
				$this->tree[$cnt]['target'] = $node[5];
				$this->tree[$cnt]['expanded'] = $node[6];
				$cnt++;
			}
		}

		/* *********************************************** */

		$this->_last_item[$menu_name] = count($this->tree);
		$this->_nodes_count = $this->_last_item[$menu_name];
		$this->tree[$this->_last_item[$menu_name] + 1]['level'] = 0;
		$this->_post_parse($menu_name);
	}

	/**
	* The method to parse the current menu table and correspondingly update related variables
	* @access public
	* @param string $menu_name the name to be attributed to the menu
	*   whose structure has to be parsed
	* @return void
	*/
	function scan_table_for_menu($menu_name = '') 
	{
		global $db;
	  
		$this->_max_level[$menu_name] = 0;
		$this->_first_level_count[$menu_name] = 0;
		unset($this->tree[$this->_nodes_count + 1]);
		$this->_first_item[$menu_name] = $this->_nodes_count + 1;


		$sql = 'SELECT ' .
      			$this->table_fields['id'] . ' AS id, ' .
      			$this->table_fields['parent_id'] . ' AS parent_id, ' .
      			$this->table_fields['text'] . ' AS text, ' .
      			$this->table_fields['link'] . ' AS link, ' .
      			$this->table_fields['title'] . ' AS title, ' .
      			$this->table_fields['icon'] . ' AS icon, ' .
      			$this->table_fields['target'] . ' AS target, ' .
      			$this->table_fields['expanded'] . ' AS expanded
	      		FROM ' . $this->table_name . '
    	  		WHERE ' . $this->table_fields['id'] . ' <> 1
      			ORDER BY ' . $this->table_fields['orderfield'] . ', ' . $this->table_fields['text'] . ' ASC';

		if(!($result = $db->sql_query($sql)))
		{
			die($sql);
		}

		$rows = $db->sql_fetchrowset($result);


		$this->_tmp_array = array();
		
		for($row_count = 0; $row_count < count($rows); $row_count++) 
		{ 
			$row = $rows[$row_count];
			$this->_tmp_array[$row['id']]['parent_id'] = $row['parent_id'];
			$this->_tmp_array[$row['id']]['text']     = $row['text'];
			$this->_tmp_array[$row['id']]['link']     = $row['link'];
			$this->_tmp_array[$row['id']]['title']    = $row['title'];
			$this->_tmp_array[$row['id']]['icon']     = $row['icon'];
			$this->_tmp_array[$row['id']]['target']   = $row['target'];
			$this->_tmp_array[$row['id']]['expanded'] = $row['expanded'];
		}

		unset($sql);
		$db->sql_freeresult($result);
		unset($row);

		$this->_depth_first_search($this->_tmp_array, $menu_name, 0, 1);

		$this->_last_item[$menu_name] = count($this->tree);
		$this->_nodes_count = $this->_last_item[$menu_name];
		$this->tree[$this->_last_item[$menu_name]+1]['level'] = 0;
		$this->_post_parse($menu_name);
	}


	/**
	* Recursive method to perform the depth-first search of the tree data taken from the current menu table
	* @access private
	* @param array $tmpArray the temporary array that stores data to perform
	*   the depth-first search
	* @param string $menu_name the name to be attributed to the menu
	*   whose structure has to be parsed
	* @param integer $parent_id id of the item whose children have
	*   to be searched for
	* @param integer $level the hierarchical level of children to be searched for
	* @return void
	*/
	function _depth_first_search($tmp_array, $menu_name, $parent_id = 0, $level)
	{
		
		foreach($tmp_array as $id => $foobar)
		{
			if ($foobar['parent_id'] == $parent_id)
			{
				unset($tmp_array[$id]);
				unset($this->_tmp_array[$id]);
				$cnt = count($this->tree) + 1;
				$this->tree[$cnt]['level'] = $level;
				$this->tree[$cnt]['text'] = $foobar['text'];
				$this->tree[$cnt]['link'] = $foobar['link'];
				$this->tree[$cnt]['title'] = $foobar['title'];
				$this->tree[$cnt]['icon'] = $foobar['icon'];
				$this->tree[$cnt]['target'] = $foobar['target'];
				$this->tree[$cnt]['expanded'] = $foobar['expanded'];
				unset($foobar);
				if ($id != $parent_id)
				{
					$this->_depth_first_search($this->_tmp_array, $menu_name, $id, $level + 1);
				}
			}
		}
	}

	/**
	* A method providing parsing needed after both file/string parsing and DB table parsing
	* @access private
	* @param string $menu_name the name of the menu for which the parsing
	*   has to be performed
	* @return void
	*/
	function _post_parse($menu_name = '')
	{
		for ($cnt = $this->_first_item[$menu_name]; $cnt <= $this->_last_item[$menu_name]; $cnt++)
		{
			$this->tree[$cnt]['child_of_root_node'] = ($this->tree[$cnt]['level'] == 1);
			$this->tree[$cnt]['parsed_text'] = stripslashes($this->tree[$cnt]['text']);
			$this->tree[$cnt]['parsed_link'] = (ereg_replace(' ', '', $this->tree[$cnt]['link']) == '') ? '#' : $this->prepended_url . $this->tree[$cnt]['link'];
			$this->tree[$cnt]['parsed_title'] = ($this->tree[$cnt]['title'] == '') ? '' : ' title="' . addslashes($this->tree[$cnt]['title']) . '"';
			$fooimg = $this->img_dir . $this->tree[$cnt]['icon'];
			if ($this->tree[$cnt]['icon'] == '' || !(file_exists($fooimg)))
			{
				$this->tree[$cnt]['parsed_icon'] = '';
			}
			else
			{
				$this->tree[$cnt]['parsed_icon'] = $this->tree[$cnt]['icon'];
				$foobar = getimagesize($fooimg);
				$this->tree[$cnt]['iconwidth'] = $foobar[0];
				$this->tree[$cnt]['iconheight'] = $foobar[1];
			}
			$this->tree[$cnt]['parsed_target'] = ($this->tree[$cnt]['target'] == '') ? '' : ' target="' . $this->tree[$cnt]['target'] . '"';
//			$this->tree[$cnt]['expanded'] = ($this->tree[$cnt]['expanded'] == '') ? 0 : $this->tree[$cnt]['expanded'];
			$this->_max_level[$menu_name] = max($this->_max_level[$menu_name], $this->tree[$cnt]['level']);
			if ($this->tree[$cnt]['level'] == 1)
			{
				$this->_first_level_count[$menu_name]++;
			}
		}
	}


	/**
	* Method that returns the code of the requested _firstLevelMenu
	* @access public
	* @param string $menu_name the name of the menu whose _firstLevelMenu
	*   has to be returned
	* @return string
	*/
	function get_menu($menu_name)
	{
		return $this->_first_level_menu[$menu_name];
	}

	/**
	* The method to set the type of images used for the Tree Menu
	* @access public
	* @return void
	*/
	function set_tree_menu_images_type($treeMenuImagesType)
	{
		$this->tree_menu_images_type = $treeMenuImagesType;
	}

	/**
	* Method to prepare a new Tree Menu.
	*
	* This method processes items of a menu to prepare and return
	* the corresponding Tree Menu code.
	*
	* @access public
	* @param string $menu_name the name of the menu whose items have to be processed
	* @return string
	*/
	function new_tree_menu($menu_name = '')
	{
		$this->_tree_menu[$menu_name] = '';

		$img_space		= $this->img_dir . 'tree_space.' . $this->tree_menu_images_type;
		$alt_space		= '  ';
		$img_vertline		= $this->img_dir . 'tree_vertline.' . $this->tree_menu_images_type;
		$alt_vertline		= '| ';
		$img_expand		= $this->img_dir . 'tree_expand.' . $this->tree_menu_images_type;
		$alt_expand		= '+-';
		$img_expand_corner	= $this->img_dir . 'tree_expand_corner.' . $this->tree_menu_images_type;
		$alt_expand_corner	= '+-';
		$img_collapse		= $this->img_dir . 'tree_collapse.' . $this->tree_menu_images_type;
		$alt_collapse		= '--';
		$img_collapse_corner	= $this->img_dir . 'tree_collapse_corner.' . $this->tree_menu_images_type;
		$alt_collapse_corner	= '--';
		$img_split		= $this->img_dir . 'tree_split.' . $this->tree_menu_images_type;
		$alt_split		= '|-';
		$img_corner		= $this->img_dir . 'tree_corner.' . $this->tree_menu_images_type;
		$alt_corner		= '`-';
		$img_folder_closed	= $this->img_dir . 'tree_folder_closed.' . $this->tree_menu_images_type;
		$alt_folder_closed	= '->';
		$img_folder_open	= $this->img_dir . 'tree_folder_open.' . $this->tree_menu_images_type;
		$alt_folder_open	= '->';
		$img_leaf		= $this->img_dir . 'tree_leaf.' . $this->tree_menu_images_type;
		$alt_leaf		= '->';

		for ($i=0; $i<=$this->_max_level[$menu_name]; $i++)
		{
			$levels[$i] = 0;
		}
		
		// Find last nodes of subtrees
		$last_level = $this->_max_level;
		for ($i = $this->_last_item[$menu_name]; $i >= $this->_first_item[$menu_name]; $i--)
		{
			if ($this->tree[$i]['level'] < $last_level)
			{
				for ($j = $this->tree[$i]['level'] + 1; $j <= $this->_max_level[$menu_name]; $j++)
				{
					$levels[$j] = 0;
				}
			}
			if ($levels[$this->tree[$i]['level']] == 0)
			{
				$levels[$this->tree[$i]['level']] = 1;
				$this->tree[$i]['last_item'] = 1;
			}
			else
			{
				$this->tree[$i]['last_item'] = 0;
			}
			$last_level = $this->tree[$i]['level'];
		}

		$toggle = '';
		$toggle_function_name = 'toggle' . $menu_name;

		for ($cnt = $this->_first_item[$menu_name]; $cnt <= $this->_last_item[$menu_name]; $cnt++)
		{
			if ($this->tree[$cnt]['parsed_link'] == '' || $this->tree[$cnt]['parsed_link'] == '#')
			{
				$this->_tree_menu[$menu_name] .= '<div id="jt' . $cnt . '" style="display: block; white-space: nowrap;" class="genmed">';
			}
			else
			{
				$this->_tree_menu[$menu_name] .= "<div id=\"jt" . $cnt . "\" style=\"display: block; white-space: nowrap;\">\n";
			}

			// vertical lines from higher levels
			for ($i = 0; $i < $this->tree[$cnt]['level'] - 1; $i++)
			{
				if ($levels[$i] == 1)
				{
					$img = $img_vertline;
					$alt = $alt_vertline;
				}
				else
				{
					$img = $img_space;
					$alt = $alt_space;
				}
				$this->_tree_menu[$menu_name] .= "<img align=\"top\" border=\"0\" class=\"imgs\" src=\"" . $img . "\" alt=\"" . $alt . "\" />";
			}

			$not_a_leaf = $cnt < $this->_last_item[$menu_name] && $this->tree[$cnt + 1]['level'] > $this->tree[$cnt]['level'];

			if ($this->tree[$cnt]['last_item'] == 1)
			{
				// corner at end of subtree or t-split
				if ($not_a_leaf)
				{
					$this->_tree_menu[$menu_name] .= "<a onmousedown=\"". $toggle_function_name . "('" . $cnt . "')\"><img align=\"top\" border=\"0\" class=\"imgs\" id=\"jt" . $cnt . "node\" src=\"" . $img_collapse_corner . "\" alt=\"" . $alt_collapse_corner . "\" /></a>";
				}
				else
				{
					$this->_tree_menu[$menu_name] .= "<img align=\"top\" border=\"0\" class=\"imgs\" src=\"" . $img_corner . "\" alt=\"" . $alt_corner . "\" />";
				}
				$levels[$this->tree[$cnt]['level']-1] = 0;
			} 
			else
			{
				if ($not_a_leaf)
				{
					$this->_tree_menu[$menu_name] .= "<a onmousedown=\"". $toggle_function_name . "('" . $cnt . "');\"><img align=\"top\" border=\"0\" class=\"imgs\" id=\"jt" . $cnt . "node\" src=\"" . $img_collapse . "\" alt=\"" . $alt_collapse . "\" /></a>";
				}
				else
				{
					$this->_tree_menu[$menu_name] .= "<a onmousedown=\"". $toggle_function_name . "('" . $cnt . "');\"><img align=\"top\" border=\"0\" class=\"imgs\" id=\"jt" . $cnt . "node\" src=\"" . $img_split . "\" alt=\"" . $alt_split . "\" /></a>";
				}
				$levels[$this->tree[$cnt]["level"]-1] = 1;
			}
			if ($this->tree[$cnt]['parsed_link'] == '' || $this->tree[$cnt]['parsed_link'] == '#')
			{
				$a_href_open = '';
				$a_href_close = '';
			}
			else
			{
				$a_href_open = "<a class=\"genmed\" href=\"" . $this->tree[$cnt]['parsed_link'] . "\"" . $this->tree[$cnt]['parsed_title'] . $this->tree[$cnt]['parsed_target'] . ">";
				$a_href_close = "</a>";
			}

			if ($not_a_leaf)
			{
				$this->_tree_menu[$menu_name] .= $a_href_open . "<img align=\"top\" border=\"0\" class=\"imgs\" id=\"jt" . $cnt . "folder\" src=\"" . $img_folder_open . "\" alt=\"" . $alt_folder_open . "\" />" . $a_href_close;
			}
			else
			{
				if ($this->tree[$cnt]['parsed_icon'] != '')
				{
					$this->_tree_menu[$menu_name] .= $a_href_open . "<img align=\"top\" border=\"0\" src=\"" . $this->img_dir . $this->tree[$cnt]['parsed_icon'] . "\" width=\"" . $this->tree[$cnt]['iconwidth'] . "\" height=\"" . $this->tree[$cnt]['iconheight'] . "\" alt=\"" . $alt_leaf . "\" />" . $a_href_close;
				}
				else
				{
					$this->_tree_menu[$menu_name] .= $a_href_open . "<img align=\"top\" border=\"0\" class=\"imgs\" src=\"" . $img_leaf . "\" alt=\"" . $alt_leaf . "\" />" . $a_href_close;
				}
			}
			$this->_tree_menu[$menu_name] .= "&nbsp;" . $a_href_open . $this->tree[$cnt]['text'] . $a_href_close . "\n";
			$this->_tree_menu[$menu_name] .= "</div>\n";

			if ($cnt < $this->_last_item[$menu_name] && $this->tree[$cnt]['level'] < $this->tree[$cnt + 1]['level'])
			{
				$this->_tree_menu[$menu_name] .= "<div id=\"jt" . $cnt . "son\" style=\"display: block; white-space: nowrap;\">\n";
				if ($this->tree[$cnt]['expanded'] != 1)
				{
					$toggle .= "if (expand[" . $cnt . "] != 1) " . $toggle_function_name . "('" . $cnt . "');\n";
				}
				else
				{
					$toggle .= "if (collapse[" . $cnt . "] == 1) " . $toggle_function_name . "('" . $cnt . "');\n";
				}
			}

			if ($cnt > $this->_first_item[$menu_name] && $this->tree[$cnt]['level'] > $this->tree[$cnt + 1]['level'])
			{
				for ($i = max(1, $this->tree[$cnt + 1]['level']); $i < $this->tree[$cnt]['level']; $i++)
				{
					$this->_tree_menu[$menu_name] .= "</div>\n";
				}
			}
		}

		$str = implode('', @file($this->lib_dir . 'layerstreemenu.ijs'));
		$temp = array(
			"toggle_function_name"	=> $toggle_function_name,
			"img_expand"		=> $img_expand,
			"img_collapse"		=> $img_collapse,
			"img_collapse_corner"	=> $img_collapse_corner,
			"img_folder_open"	=> $img_folder_open,
			"img_expand_corner"	=> $img_expand_corner,
			"img_folder_closed"	=> $img_folder_closed);
		
		$preg_replace = array('vars' => array(), 'replacement' => array());
		
		foreach($temp as $vars => $rep)
		{
			$preg_replace['vars'][] = '/' . preg_quote('{' . $vars . '}') . '/';
			$preg_replace['replacement'][] = $rep;
		}		
			
		$toggle_function = @preg_replace($preg_replace['vars'], $preg_replace['replacement'], $str);

		$toggle_function =
		"<script language=\"JavaScript\" type=\"text/javascript\">\n" .
		"<!--\n" .
		$toggle_function .
		"// -->\n" .
		"</script>\n";

		$toggle =
		"<script language=\"JavaScript\" type=\"text/javascript\">\n" .
		"<!--\n" .
		"if ((DOM && !Opera56 && !Konqueror2) || IE4) {\n" .
		$toggle .
		"}\n" .
		"if (NS4) alert('Only the accessibility is provided to Netscape 4 on the JavaScript Tree Menu.\\nWe *strongly* suggest you to upgrade your browser.');\n" .
		"// -->\n" .
		"</script>\n";

		$this->_tree_menu[$menu_name] = $toggle_function . "\n" . $this->_tree_menu[$menu_name] . "\n" . $toggle;

		return $this->_tree_menu[$menu_name];
	}

	/**
	* Method that returns the code of the requested Tree Menu
	* @access public
	* @param string $menu_name the name of the menu whose Tree Menu code
	*   has to be returned
	* @return string
	*/
	function get_tree_menu($menu_name)
	{
		return $this->_tree_menu[$menu_name];
	}


	/**
	* Method to handle errors
	* @access private
	* @param string $errormsg the error message
	* @return void
	*/
	function error($error_msg)
	{
		$this->error[] = $error_msg;

	}

} /* END OF CLASS */

?>
